pub const ALLOC: i128 = 0x47;
pub const DEALLOC: i128 = 0x48;
pub const THROW: i128 = 0x64;
pub const RETURN: i128 = 0x38;
pub const CALL: i128 = 0x29;
pub const RETURN_C: i128 = RETURN * 2;
